@@ -226,13 +226,14 @@ END
       --or --field=Priority important --or --field=Priority standard \
       \))
 
-  pkgs="$pkgs build-essential busybox gpg eatmydata fakechroot fakeroot"
+  pkgs="$pkgs build-essential busybox eatmydata fakechroot fakeroot"
 
   # we need usr-is-merged to simulate debootstrap behaviour for all dists
   # starting from Debian 12 (Bullseye)
   case "$dist" in
-    oldstable) : ;;
-    *) pkgs="$pkgs usr-is-merged usrmerge" ;;
+    oldstable) pkgs="$pkgs gpg" ;;
+    stable) pkgs="$pkgs gpg usr-is-merged usrmerge" ;;
+    testing | unstable) pkgs="$pkgs gpg-from-sq" ;;
   esac
 
   # shellcheck disable=SC2086
@@ -459,7 +460,7 @@ if [ "$HAVE_QEMU" = "yes" ]; then
   tmpdir="$(mktemp -d)"
   trap 'kill "$PROXYPID" || :;cleanuptmpdir; cleanup_newcachedir' EXIT INT TERM
 
-  pkgs=perl-doc,systemd-sysv,perl,arch-test,fakechroot,fakeroot,mount,uidmap,qemu-user-binfmt,dpkg-dev,mini-httpd,libdevel-cover-perl,libtemplate-perl,debootstrap,procps,apt-cudf,aspcud,python3,libcap2-bin,gpg,debootstrap,distro-info-data,iproute2,ubuntu-keyring,apt-utils,squashfs-tools-ng,genext2fs,linux-image-generic,passwd,e2fsprogs,uuid-runtime
+  pkgs=perl-doc,systemd-sysv,perl,arch-test,fakechroot,fakeroot,mount,uidmap,qemu-user-binfmt,dpkg-dev,mini-httpd,libdevel-cover-perl,libtemplate-perl,debootstrap,procps,apt-cudf,aspcud,python3,libcap2-bin,gpg-from-sq,debootstrap,distro-info-data,iproute2,ubuntu-keyring,apt-utils,squashfs-tools-ng,genext2fs,linux-image-generic,passwd,e2fsprogs,uuid-runtime
   if [ ! -e ./mmdebstrap ]; then
     pkgs="$pkgs,mmdebstrap"
   fi
